@@ -95,6 +95,9 @@ var _extraDirs = []extraDir{
 	{
 		originDir: "/var/lib/systemd",
 	},
+	{
+		originDir: "/var/lib/dkms",
+	},
 	{
 		originDir: "/var/uos",
 		specifiedFiles: []string{
@@ -366,10 +369,12 @@ func backup(cfg *Config, envVars []string) error {
 	}()
 
 	skipDirs := []string{
-		"/media", "/tmp", "/proc", "/sys", "/dev", "/run",
+		"/media", "/tmp", "/proc", "/sys", "/dev", "/run", "/mnt", "/boot", "/data", "/lost+found", "/recovery", "/opt",
 	}
-
-	tmpExcludeFile, err := writeExcludeFile(append(skipDirs, backupMountPoint))
+	skipFiles := []string{
+		"/usr/share/deepin-home-appstore-daemon/appstore.db",
+	}
+	tmpExcludeFile, err := writeExcludeFile(append(append(skipDirs, backupMountPoint), skipFiles...))
 	if err != nil {
 		return xerrors.Errorf("failed to write exclude file: %w", err)
 	}
@@ -417,6 +422,7 @@ func backup(cfg *Config, envVars []string) error {
 	backupExtra()
 	errMsg, err := runRsync(tmpExcludeFile)
 	if err != nil {
+		logger.Warning(errMsg)
 		allMatchedString := _renameFailedMsgRegexp.FindAllStringSubmatch(errMsg, -1)
 		for _, matchString := range allMatchedString {
 			if len(matchString) == 3 {
@@ -529,6 +535,7 @@ func runRsync(excludeFile string) (string, error) {
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = &errBuffer
 	cmd.Env = append(cmd.Env, "LC_ALL=C")
+	logger.Info("run rsync...cmd: ", cmd.String())
 	err := cmd.Run()
 	return errBuffer.String(), err
 }
@@ -541,7 +548,13 @@ func backupKernel() (kFiles *kernelFiles, err error) {
 		}
 	}
 
-	err = os.Rename(globalKernelBackupDir, globalKernelBackupDir+".old")
+	// 移除无需要的备份文件
+	err = os.RemoveAll(abKernelBackupDir)
+	if err != nil {
+		logger.Warning(err)
+	}
+
+	err = os.RemoveAll(globalKernelBackupDir)
 	if err != nil {
 		if !os.IsNotExist(err) {
 			return
@@ -593,13 +606,6 @@ func backupKernel() (kFiles *kernelFiles, err error) {
 		}
 	}
 
-	err = os.RemoveAll(globalKernelBackupDir + ".old")
-	if err != nil {
-		if !os.IsNotExist(err) {
-			return
-		}
-	}
-
 	return
 }
 
@@ -813,52 +819,20 @@ func restore(cfg *Config, envVars []string) error {
 		}
 	}
 
-	// 创建备份文件夹
-	err = os.MkdirAll(abKernelBackupDir, 0755)
-	if err != nil {
-		return xerrors.Errorf("failed to make dir %s: %w", abKernelBackupDir, err)
-	}
-
-	// 移动内核文件到/boot/kernel-backup/
-	fileInfoList, err := ioutil.ReadDir(globalBootDir)
-	if err != nil {
-		return xerrors.Errorf("failed to read dir %s: %w", globalBootDir, err)
-	}
-	prefixes := []string{"vmlinuz-", "vmlinux-", "kernel-", "initrd"}
-	for _, fix := range prefixes {
-		for _, info := range fileInfoList {
-			if info.IsDir() {
-				continue
-			}
-			if strings.Contains(info.Name(), fix) {
-				err = os.Rename(filepath.Join(globalBootDir, info.Name()),
-					filepath.Join(abKernelBackupDir, info.Name()))
-				if err != nil {
-					logger.Warning("backup kernel failed:", info.Name(), err)
-				}
-			}
-		}
-	}
-
 	// 将/boot/deepin-ab-recovery文件内核文件移动到 /boot
-	fileInfoList, err = ioutil.ReadDir(globalKernelBackupDir)
+	fileInfoList, err := ioutil.ReadDir(globalKernelBackupDir)
 	if err != nil {
 		return xerrors.Errorf("failed to read dir %s: %w", globalKernelBackupDir, err)
 	}
 
 	for _, info := range fileInfoList {
-		err = utils.CopyFile(filepath.Join(globalKernelBackupDir, info.Name()), filepath.Join(globalBootDir, info.Name()))
+		err = os.Rename(filepath.Join(globalKernelBackupDir, info.Name()), filepath.Join(globalBootDir, info.Name()))
 		if err != nil {
 			logger.Warning("copy recovery file failed:", err)
 			return err
 		}
 	}
 
-	err = os.RemoveAll(globalKernelBackupDir)
-	if err != nil {
-		logger.Warning("Remove dir failed:", globalKernelBackupDir, err)
-	}
-
 	err = writeBootloaderCfgRestore(cfg.Current, currentDevice, cfg.Backup, envVars)
 	if err != nil {
 		return xerrors.Errorf("failed to write grub cfg: %w", err)
@@ -934,7 +908,7 @@ func restore(cfg *Config, envVars []string) error {
 	}
 
 	adapterActivator()
-
+	doRestoreHooks()
 	return nil
 }
 
@@ -1406,12 +1380,33 @@ func initBackUpRecord(recordPath, hospice string) {
 
 // 在还原过程中适配系统激活
 func adapterActivator() {
-	err := exec.Command("pkill", "-ef", "/usr/lib/deepin-daemon/uos-license-agent").Run()
+	_, err := os.Stat("/var/uos/.licenseadapter")
+	if err == nil {
+		// 系统进行还原操作时，通过root权限运行程序 /var/uos/.licenseadapter
+		err = exec.Command("/var/uos/.licenseadapter").Run()
+		if err != nil {
+			logger.Warning("run /var/uos/.licenseadapter failed", err)
+		}
+	} else {
+		logger.Warning("/var/uos/.licenseadapter stat err: ", err)
+	}
+}
+
+// /var/lib/deepin-ab-recovery/hooks用于其他模块存放脚本(类似bug 114537的问题)，在进行回滚的时候，执行对应脚本
+func doRestoreHooks() {
+	const restoreHookDir = "/var/lib/deepin-ab-recovery/hooks"
+	infos, err := ioutil.ReadDir(restoreHookDir)
 	if err != nil {
-		logger.Warning("failed to kill uos-license-agent:", err)
+		logger.Warning(err)
+		return
 	}
-	err = exec.Command("pkill", "-ef", "/usr/bin/uos-activator").Run()
-	if err != nil {
-		logger.Warning("failed to kill uos-activator:", err)
+	for _, info := range infos {
+		if !info.IsDir() {
+			path := filepath.Join(restoreHookDir, info.Name())
+			err = exec.Command(path).Run()
+			if err != nil {
+				logger.Warning("run this hook failed: ", err)
+			}
+		}
 	}
 }
